@@ -1,32 +1,38 @@
-# coding: utf-8
 """
     cairocffi.pixbuf
     ~~~~~~~~~~~~~~~~
 
     Loading various image formats with GDK-PixBuf
 
-    :copyright: Copyright 2013 by Simon Sapin
+    :copyright: Copyright 2013-2019 by Simon Sapin
     :license: BSD, see LICENSE for details.
 
 """
 
 import sys
-from io import BytesIO
-from functools import partial
 from array import array
+from functools import partial
+from io import BytesIO
 
-from . import dlopen, ImageSurface, Context, constants
-from ._ffi_pixbuf import ffi
-from .compat import xrange
-
+from . import Context, ImageSurface, constants, dlopen
+from .ffi import ffi_pixbuf as ffi
 
 __all__ = ['decode_to_image_surface']
 
-gdk_pixbuf = dlopen(ffi, 'gdk_pixbuf-2.0', 'gdk_pixbuf-2.0-0')
-gobject = dlopen(ffi, 'gobject-2.0', 'gobject-2.0-0')
-glib = dlopen(ffi, 'glib-2.0', 'glib-2.0-0')
+gdk_pixbuf = dlopen(
+    ffi, ('gdk_pixbuf-2.0', 'libgdk_pixbuf-2.0-0'),
+    ('libgdk_pixbuf-2.0.so.0', 'libgdk_pixbuf-2.0.0.dylib',
+     'libgdk_pixbuf-2.0-0.dll'))
+gobject = dlopen(
+    ffi, ('gobject-2.0', 'libgobject-2.0-0'),
+    ('libgobject-2.0.so.0', 'libgobject-2.0.dylib', 'libgobject-2.0-0.dll'))
+glib = dlopen(
+    ffi, ('glib-2.0', 'libglib-2.0-0'),
+    ('libglib-2.0.so.0', 'libglib-2.0.dylib', 'libglib-2.0-0.dll'))
 try:
-    gdk = dlopen(ffi, 'gdk-3', 'gdk-x11-2.0', 'gdk-win32-2.0-0')
+    gdk = dlopen(
+        ffi, ('gdk-3', 'libgdk-3-0'),
+        ('libgdk-3.so.0', 'libgdk-3.0.dylib', 'libgdk-3-0.dll'))
 except OSError:
     gdk = None
 
@@ -90,7 +96,7 @@ def decode_to_pixbuf(image_data, width=None, height=None):
     if width and height:
         gdk_pixbuf.gdk_pixbuf_loader_set_size(loader, width, height)
     handle_g_error(error, gdk_pixbuf.gdk_pixbuf_loader_write(
-        loader, ffi.new('guchar[]', image_data), len(image_data), error))
+        loader, image_data, len(image_data), error))
     handle_g_error(error, gdk_pixbuf.gdk_pixbuf_loader_close(loader, error))
 
     format_ = gdk_pixbuf.gdk_pixbuf_loader_get_format(loader)
@@ -165,7 +171,7 @@ def pixbuf_to_cairo_slices(pixbuf):
     pixbuf_row_length = width * 3  # stride == row_length + padding
     cairo_row_length = width * 4  # stride == row_length + padding
     alpha = b'\xff' * width  # opaque
-    for y in xrange(height):
+    for y in range(height):
         offset = rowstride * y
         end = offset + pixbuf_row_length
         red = pixels[offset:end:3]
